@@ -122,7 +122,9 @@ class About(gtk.Dialog):
         label.set_use_markup(1)
         self.vbox.pack_start(label)
 
-        self.vbox.pack_start(gtk.Label(text))
+        label = gtk.Label(text)
+        label.set_line_wrap(gtk.WRAP_WORD)
+        self.vbox.pack_start(label)
 
         s = copyright.replace("<", "&lt;").replace(">", "&gt;")
         label = gtk.Label('<span size="smaller">%s</span>' % s)
