@@ -1,5 +1,5 @@
-# GNU Solfege - eartraining for GNOME
-# Copyright (C) 2000, 2001, 2002, 2003  Tom Cato Amundsen
+# GNU Solfege - ear training for GNOME
+# Copyright (C) 2000, 2001, 2002, 2003, 2004  Tom Cato Amundsen
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -39,7 +39,7 @@ class RestRequest(ItHasDuration):
         return "(RestRequest:%s)" % self.m_duration
 
 
-class Music(ItHasDuration):
+class MusicRequest(ItHasDuration):
     def __init__(self, notename, duration, dots):
         ItHasDuration.__init__(self, duration, dots)
         self.m_pitch = MusicalPitch.new_from_notename(notename)
