@@ -1,7 +1,7 @@
 #!/usr/bin/python
 
 # GNU Solfege - ear training for GNOME
-# Copyright (C) 2000, 2001, 2002, 2003, 2004  Tom Cato Amundsen
+# Copyright (C) 2000, 2001, 2002, 2003, 2004, 2005  Tom Cato Amundsen
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -23,10 +23,6 @@
 import sys
 import os
 import src
-import src.configureoutput
-
-src.configureoutput.prefix = "."
-src.configureoutput.datadir = "."
 import src.cfg
 
 import src.gethomedir
@@ -36,8 +32,14 @@ if not os.path.exists(src.gethomedir.get_home_dir()):
 if sys.platform == 'win32':
     print "Using as home dir:", src.gethomedir.get_home_dir()
 
-src.cfg.initialise(None, "default.config", 
+src.cfg.initialise("default.config", None,
                    os.path.join(src.gethomedir.get_home_dir(), ".solfegerc"))
 
+# i18n should be imported very early in program init because it setup
+# the _ and _i functions for the whole program.
+import src.i18n
+src.i18n.setup(".")
+
 import src.mainwin
 
+src.mainwin.start_app(".", ".")
