@@ -21,7 +21,11 @@ import winmidi
 class WinSynth:
     NUM_CHANNELS = 16
     def __init__(self, devnum, verbose_init):
-        self.__driver = winmidi.Winmidi(devnum)
+        try:
+            self.__driver = winmidi.Winmidi(devnum)
+        except RuntimeError, e:
+            devnum = 0
+            self.__driver = winmidi.Winmidi(devnum)
         self.m_type_major = "win32" #FIXME
         self.m_devnum = devnum
         if verbose_init:
