@@ -122,14 +122,12 @@ class LessonbasedTeacher(Teacher):
 You really should reastart the program now.""")
         if filter(lambda q: q['music'].m_musictype == 'cmdline',
                   self.m_P.m_questions):
-            run = self.m_app.m_ui.dialog_yesno(_("The lessonfile contain potentially dangerous code because it run external programs. Run anyway?"))
+            run = gu.dialog_yesno(_("The lessonfile contain potentially dangerous code because it run external programs. Run anyway?"))
             if not run:
                 self.m_P = None
     def check_askfor(self):
-        if self.get_bool('gui/expert_mode'):
+        if self.m_custom_mode:
             self.set_list('ask_for_names', range(len(self.m_P.get_unique_cnames())))
-            for question in self.m_P.m_questions:
-                question['active'] = 1
 
 class MelodicIntervalTeacher(LessonbasedTeacher):
     """
@@ -284,10 +282,10 @@ class Gui(gtk.VBox, cfg.ConfigUtils):
         req = self.m_t.m_P.get_test_requirement()
         res = self.m_t.m_statistics.get()
         if res >= req:
-            self.g_win.dialog_ok(_("Test completed!\nYour score was %.1f%%.\nThe test requirement was %.1f%%.") % (res * 100, req * 100))
+            gu.dialog_ok(_("Test completed!\nYour score was %.1f%%.\nThe test requirement was %.1f%%.") % (res * 100, req * 100))
             self.m_t.m_statistics.store_test_passed()
         else:
-            self.g_win.dialog_ok(_("Test failed.\nYour score was %.1f%%.\nThe test requirement was %.1f%%.") % (res * 100, req * 100))
+            gu.dialog_ok(_("Test failed.\nYour score was %.1f%%.\nThe test requirement was %.1f%%.") % (res * 100, req * 100))
         self.g_cancel_test.hide()
         self.g_win.exit_test_mode()
     def set_lesson_heading(self, txt):
