@@ -77,6 +77,7 @@ True
 
 import re
 import os, os.path, sys
+import gethomedir
 
 section_re = re.compile("^\[([\w-]*?)\]")
 value_re = re.compile(  "^([\w-]*?)=(.*)")
@@ -306,7 +307,7 @@ def initialise(app_defaults_filename, system_filename, user_filename):
     _blocked_watches = {}
     _app_defaults_filename = app_defaults_filename
     _system_filename = system_filename
-    _user_filename = user_filename = os.path.expanduser(user_filename)
+    _user_filename = user_filename = gethomedir.expanduser(user_filename)
     if app_defaults_filename:
         try:
             data = parse_file_into_dict({}, app_defaults_filename)
