@@ -360,7 +360,10 @@ class Dataparser:
         while 1:
             if peek == '+':
                 self._lexer.scan_any()
-                faktor += self.atom()
+                if isinstance(faktor, _TranslatedString):
+                    faktor = faktor.i18name % self.atom()
+                else:
+                    faktor += self.atom()
             elif peek == '-':
                 self._lexer.scan_any()
                 faktor -= self.atom()
@@ -369,7 +372,10 @@ class Dataparser:
                 faktor = (faktor, self.atom())
             elif peek == '%':
                 self._lexer.scan_any()
-                faktor = faktor % self.atom()
+                if isinstance(faktor, _TranslatedString):
+                    faktor = faktor.i18name % self.atom()
+                else:
+                    faktor = faktor % self.atom()
             else:
                 break
             peek = self._lexer.peek_type()
