@@ -15,19 +15,10 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
-__exercise_data__ = {
-    'exercise_name': 'dictation',
-    'stock-icon': 'solfege-dictation',
-    'menupath': '/Menubar/FileMenu/MiscMenu',
-    'name': _('_Dictation'),
-}
-import exercise_setup
-exercise_setup.register_exercise(__exercise_data__)
-
 import os
 
 import gtk, gnome
-import gu, widgets
+import gu
 import mpd, mpd.musicdisplayer
 import abstract, const, lessonfile
 from soundcard.rat import Rat
@@ -37,7 +28,6 @@ import configureoutput
 import dataparser
 
 class Teacher(abstract.LessonbasedTeacher):
-    exercise_data = __exercise_data__
     """
     The Teacher and Gui for dictation abuses q_status a little.
     QSTATUS_NEW mean that the lessonfile is ok.
@@ -50,7 +40,7 @@ class Teacher(abstract.LessonbasedTeacher):
 
 class Gui(abstract.LessonbasedGui):
     def __init__(self, teacher, window):
-        abstract.LessonbasedGui.__init__(self, teacher, window)
+        abstract.LessonbasedGui.__init__(self, teacher, window, no_notebook=1)
         ################
         # practise_box #
         ################
@@ -77,11 +67,6 @@ class Gui(abstract.LessonbasedGui):
         self.g_play = gu.bButton(self.action_area, _("_Play the whole music"),
                                  self.play)
         self.g_show = gu.bButton(self.action_area, _("_Show"), self.show_answer)
-        ##############
-        # config_box #
-        ##############
-        self.add_select_lessonfile_gui()
-        self.update_gui_after_lessonfile_change()
     def exception_cleanup(self):
         """ cleanup function after exception caught in select_previous
         and select_next
@@ -208,35 +193,31 @@ class Gui(abstract.LessonbasedGui):
                         fontsize, mpd.FIRST)
     def update_gui_after_lessonfile_change(self):
         self.m_t.q_status = const.QSTATUS_NEW
-        if self.m_t.m_P:
-            if not self.m_t.m_P.m_questions:
-                self.g_win.display_error_message(_("The lesson file '%s' contains no questions.") % self.get_string('lessonfile'))
-                self.g_play.set_sensitive(False)
-                self.g_show.set_sensitive(False)
-                self.g_go_back.set_sensitive(False)
-                self.g_go_forward.set_sensitive(False)
-                self._update()
-                return
-            else:
-                self.g_go_forward.set_sensitive(True)
-                self.g_go_back.set_sensitive(True)
-            self.m_t.m_P.select_first()
-            self.action_area.set_sensitive(True)
-            try:
-                self.display_start_of_music()
-            except mpd.MpdException, e:
-                self.g_win.display_question_music_error_message(
-                    self.m_t.m_P._idx, self.get_string('lessonfile'), e, __file__)
-                self.m_t.q_status = const.QSTATUS_NO
-                self.g_play.set_sensitive(False)
-                self.g_show.set_sensitive(False)
-                self.g_music_displayer.clear()
-            else:
-                self.g_play.set_sensitive(True)
-                self.g_show.set_sensitive(True)
+        if not self.m_t.m_P.m_questions:
+            self.g_win.display_error_message(_("The lesson file '%s' contains no questions.") % self.get_string('lessonfile'))
+            self.g_play.set_sensitive(False)
+            self.g_show.set_sensitive(False)
+            self.g_go_back.set_sensitive(False)
+            self.g_go_forward.set_sensitive(False)
+            self._update()
+            return
         else:
+            self.g_go_forward.set_sensitive(True)
+            self.g_go_back.set_sensitive(True)
+        self.m_t.m_P.select_first()
+        self.action_area.set_sensitive(True)
+        try:
+            self.display_start_of_music()
+        except mpd.MpdException, e:
+            self.g_win.display_question_music_error_message(
+                self.m_t.m_P._idx, self.get_string('lessonfile'), e, __file__)
+            self.m_t.q_status = const.QSTATUS_NO
+            self.g_play.set_sensitive(False)
+            self.g_show.set_sensitive(False)
             self.g_music_displayer.clear()
-            self.action_area.set_sensitive(False)
+        else:
+            self.g_play.set_sensitive(True)
+            self.g_show.set_sensitive(True)
         self._update()
     def create_pixmap_button(self):
         im = gtk.Image()
@@ -246,5 +227,6 @@ class Gui(abstract.LessonbasedGui):
         btn.add(im)
         return btn
     def on_start_practise(self):
+        self.update_gui_after_lessonfile_change()
         self.g_play.grab_focus()
 
