@@ -1,5 +1,5 @@
 # GNU Solfege - ear training for GNOME
-# Copyright (C) 2005  Tom Cato Amundsen
+# Copyright (C) 2005, 2006 Tom Cato Amundsen
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -17,6 +17,7 @@
 
 import os
 import sys
+import locale
 
 def _get_home_dir():
     ''' Try to find user's home directory, otherwise return current directory.'''
@@ -50,6 +51,11 @@ def get_home_dir():
         try:
             return _get_home_dir().decode(enc)
         except UnicodeDecodeError, e:
-            return _get_home_dir().decode("iso-8859-1")
+            try:
+                return _get_home_dir().decode(locale.getpreferredencoding())
+            except UnicodeDecodeError, e:
+                return _get_home_dir().decode("iso-8859-1")
     return _get_home_dir()
-    
+
+def expanduser(s):
+    return s.replace("~", get_home_dir())
