@@ -71,14 +71,14 @@ class Teacher(abstract.LessonbasedTeacher):
         """
         if answer == self.m_P.get_cname():
             if self.q_status == const.QSTATUS_NEW \
-                    and not self.get_bool('gui/expert_mode'):
+                    and not self.m_custom_mode:
                 self.m_statistics.add_correct(answer)
             self.maybe_auto_new_question()
             self.q_status = const.QSTATUS_SOLVED
             return 1
         else:
             if self.q_status == const.QSTATUS_NEW:
-                if not self.get_bool('gui/expert_mode'):
+                if not self.m_custom_mode:
                     self.m_statistics.add_wrong(self.m_P.get_cname(), answer)
                 self.q_status = const.QSTATUS_WRONG
             if self.m_app.m_test_mode:
@@ -173,11 +173,11 @@ class Gui(abstract.LessonbasedGui):
                       self.m_t.m_P.header.labelformat, self.on_click)
         else:
             self.g_bb.initialize(0, 0)
-        if self.m_t.m_P and self.get_bool('gui/expert_mode'):
+        if self.m_t.m_P and self.m_t.m_custom_mode:
             self.g_bb.ask_for_names_changed()
     def update_select_question_buttons(self):
         #FIXME duplicate code in src/chord.py
-        if self.get_bool('gui/expert_mode'):
+        if self.m_t.m_custom_mode:
             self.g_select_questions_category_box.show()
             self.g_select_questions.initialize(self.m_t.m_P.header.fillnum,
                                  self.m_t.m_P.header.filldir)
@@ -371,9 +371,12 @@ class Gui(abstract.LessonbasedGui):
         self.g_bb.grab_focus_first_button()
         self.m_t.m_P.play_question_slowly()
     def on_start_practise(self):
+        self.m_t.m_custom_mode = self.get_bool('gui/expert_mode')
+        for question in self.m_t.m_P.m_questions:
+            question['active'] = 1
         self.setup_action_area_buttons()
-        self.update_answer_buttons()
         self.update_select_question_buttons()
+        self.update_answer_buttons()
         self.set_lesson_heading(self.m_t.m_P.header.lesson_heading)
         self.g_random_transpose.set_text(str(self.m_t.m_P.header.random_transpose))
         self.g_flashbar.require_size([
@@ -385,7 +388,7 @@ class Gui(abstract.LessonbasedGui):
             _("You have to select some questions to practise."),
         ])
         self.g_new.grab_focus()
-        if not self.get_bool('gui/expert_mode'):
+        if not self.m_t.m_custom_mode:
             self.m_t.m_statistics.reset_session()
         self.g_music_displayer.clear()
         if self.m_t.m_app.m_test_mode:
