@@ -35,6 +35,7 @@ class Teacher(abstract.LessonbasedTeacher):
         self.m_statistics = statistics.LessonStatistics(self)
         self.m_ask_tones =   {}
         self.m_question = None
+        self.m_custom_mode = False
     def new_question(self):
         """
         Return values:
@@ -72,14 +73,14 @@ class Teacher(abstract.LessonbasedTeacher):
     def guess_answer(self, notename):
         if notename == self.m_question:
             if self.q_status == const.QSTATUS_NEW \
-                    and not self.get_bool('gui/expert_mode'):
+                    and not self.m_custom_mode:
                 self.m_statistics.add_correct(notename)
             self.maybe_auto_new_question()
             self.q_status = const.QSTATUS_SOLVED
             return 1
         else:
             if self.q_status == const.QSTATUS_NEW:
-                if not self.get_bool('gui/expert_mode'):
+                if not self.m_custom_mode:
                     self.m_statistics.add_wrong(self.m_question, notename)
                 self.q_status = const.QSTATUS_WRONG
     def play_question(self):
@@ -89,7 +90,7 @@ class Teacher(abstract.LessonbasedTeacher):
              mpd.notename_to_int(self.m_question)+self.m_octave*12,
              self.get_int('config/preferred_instrument_velocity'))
     def give_up(self):
-        if not self.get_bool('gui/expert_mode'):
+        if not self.m_custom_mode:
             self.m_statistics.reset_session()
         self.q_status = const.QSTATUS_GIVE_UP
     def spank_me_play_question(self):
@@ -254,6 +255,9 @@ _("""You have to select some tones practise. Do this on the config page by setti
     def on_start_practise(self):
         if not self.m_usable:
             return
+        self.m_t.m_custom_mode = not (
+                ('white_keys_weight' in self.m_t.m_P.header)
+                 or ('black_keys_weight' in self.m_t.m_P.header))
         self.g_flashbar.require_size([
             _("Click 'New tone' to begin."),
             _("Correct, but you have already solved this question"),
@@ -275,7 +279,7 @@ _("""You have to select some tones practise. Do this on the config page by setti
                     self.set_float('%s_weight' % n, self.m_t.m_P.header.black_keys_weight[idx])
             else:
                 print "black_keys_weight had wrong type"
-        if self.get_bool('gui/expert_mode'):
+        if self.m_t.m_custom_mode:
             self.g_config_elems.show()
         else:
             self.g_config_elems.hide()
