@@ -118,7 +118,10 @@ predef = {'dictation': 'dictation',
           'semitones': 'semitones',
           'play': 'play',
           'show': 'show',
-          'tempo': (60, 4)}
+          'tempo': (60, 4),
+          # Used by the rhythm module:
+          'newline': 'newline',
+          }
 
 lessonfile_functions = {
         '_': dataparser.dataparser_i18n_func,
