@@ -165,6 +165,7 @@ import gu
 import cfg
 import stock
 import lessonfile
+import lessonfilegui
 import abstract
 
 import chord
@@ -187,41 +188,7 @@ import singanswer
 import learning_tree_editor
 from docviewer import DocViewer
 from helpbrowser import HelpBrowser
-
-class ResolveLessonIdCrashDlg(gtk.Dialog):
-    def __init__(self, lessonfile_manager, lesson_id):
-        gtk.Dialog.__init__(self, _("Resolve lesson_id crash"), None,
-            buttons=(gtk.STOCK_CANCEL, gtk.RESPONSE_CANCEL,
-                     gtk.STOCK_OK, gtk.RESPONSE_OK))
-        vbox = gtk.VBox()
-        vbox.set_border_width(12)
-        self.vbox.pack_start(vbox)
-        msg1 = gtk.Label("<b>%s</b>" % _("Lesson_id crash"))
-        msg1.set_alignment(0.0, 0.5)
-        msg1.set_use_markup(True)
-        vbox.pack_start(msg1, False)
-        msg2 = gtk.Label(_("The lesson_id has to be unique for each lesson file. Please select which lesson file shall keep the current lesson_id. The preselected file is Solfege's educated guess. Press 'Cancel' to postpone the decision."))
-        msg2.set_alignment(0.0, 0.5)
-        msg2.set_line_wrap(True)
-        vbox.pack_start(msg2)
-        self.radio_dict = {}
-        for info in lessonfile_manager.get_lesson_file_info(lesson_id):
-            if self.radio_dict.keys():
-                g = self.radio_dict[self.radio_dict.keys()[0]]
-            else:
-                g = None
-            ss = "%s %s" % (info['filename'], info['timestr'])
-            if not isinstance(ss, unicode):
-                ss = ss.decode(locale.getpreferredencoding(), 'replace')
-            radiobutton = gtk.RadioButton(g, ss)
-            radiobutton.show()
-            radiobutton.set_data('fn', info['filename'])
-            radiobutton.set_data('lessonfile', info['lessonfile'])
-            radiobutton.set_data('lessoncollection', info['lessoncollection'])
-            self.radio_dict[info['mtime']] = radiobutton
-            vbox.pack_start(radiobutton)
-        self.radio_dict[min(self.radio_dict.keys())].set_active(True)
-        self.show_all()
+import gethomedir
 
 class MusicViewerWindow(gtk.Dialog):
     def __init__(self, app):
@@ -294,11 +261,11 @@ class MainWin(gnome.ui.App, cfg.ConfigUtils):
                 self.m_tree.load(filename)
             else:
                 assert loc == 'user'
-                self.m_tree.load(os.path.join(os.path.expanduser('~'), '.solfege', 'learningtrees', filename))
+                self.m_tree.load(os.path.join(gethomedir.get_home_dir(), '.solfege', 'learningtrees', filename))
         except IOError:
             self.m_tree.load(self.default_learning_tree[1])
             self.set_list('app/learningtree', self.default_learning_tree)
-            self.dialog_ok(_("Learning tree '%s' not found. Using default tree." % filename))
+            gu.dialog_ok(_("Learning tree '%s' not found. Using default tree." % filename))
         self.create_practise_and_test_menu()
     def setup_menu(self):
         self.m_action_groups['Exit'].add_actions([
@@ -351,7 +318,7 @@ class MainWin(gnome.ui.App, cfg.ConfigUtils):
         if self.m_learning_trees_merge_id:
             self.g_ui_manager.remove_ui(self.m_learning_trees_merge_id)
         try:
-            v = os.listdir(os.path.expanduser("~/.solfege/learningtrees"))
+            v = os.listdir(os.path.join(gethomedir.get_home_dir(), ".solfege", "learningtrees"))
         except OSError:
             v = []
         if not v:
@@ -383,6 +350,7 @@ class MainWin(gnome.ui.App, cfg.ConfigUtils):
         actions = []
         if self.m_practise_and_test_merge_id:
             self.g_ui_manager.remove_ui(self.m_practise_and_test_merge_id)
+            self.g_ui_manager.ensure_update()
         s = """
 <menubar name='Menubar'>
  <menu action='PractiseMenu'>"""
@@ -439,23 +407,6 @@ class MainWin(gnome.ui.App, cfg.ConfigUtils):
             return
         self.g_ui_manager.remove_ui(self.m_help_on_current_merge_id)
         self.m_help_on_current_merge_id = None
-    def dialog_ok(self, text):
-        """"
-        Return the gtk.RESPONSE_XXXX returned by .run()
-        """
-        m = gtk.MessageDialog(self, gtk.DIALOG_MODAL, gtk.MESSAGE_INFO,
-                gtk.BUTTONS_OK, text)
-        ret = m.run()
-        m.destroy()
-        return ret
-    def dialog_yesno(self, text):
-        """Return True if the answer is yes, False if the answer is no.
-        """
-        m = gtk.MessageDialog(self, gtk.DIALOG_MODAL, gtk.MESSAGE_QUESTION,
-                gtk.BUTTONS_YES_NO, text)
-        ret = m.run()
-        m.destroy()
-        return ret == gtk.RESPONSE_YES
     def show_bug_reports(self, *v):
         m = gtk.Dialog(_("Question"), self, 0)
         m.add_button(gtk.STOCK_CANCEL, gtk.RESPONSE_CANCEL)
@@ -557,7 +508,7 @@ This program is distributed in the hope that it will be useful, but WITHOUT ANY
             win.load_file(filename)
         else:
             assert loc == 'user'
-            win.load_file(os.path.join(os.path.expanduser('~'), '.solfege', 'learningtrees', filename))
+            win.load_file(os.path.join(gethomedir.get_home_dir(), '.solfege', 'learningtrees', filename))
         win.show()
         x, y = win.g_topic_scrollwin.size_request()
         win.g_lesson_scrollwin.set_size_request(x, int(y*1.6))
@@ -669,31 +620,6 @@ This program is distributed in the hope that it will be useful, but WITHOUT ANY
         # rebuild the menus in case we hav passed a test.
         self.create_practise_and_test_menu()
 
-def handle_lesson_id_crash(lessonfile_manager):
-    for lesson_id in lessonfile_manager.iterate_duplicated_lesson_id():
-        if splash_win:
-            splash_win.hide()
-        dlg = ResolveLessonIdCrashDlg(lessonfile_manager, lesson_id)
-        ret = dlg.run()
-        if ret == gtk.RESPONSE_OK:
-            for b in dlg.radio_dict.values():
-                # Create a new lesson_id and parse them into m_uiddb
-                if not b.get_active():
-                    f = lessonfile.LessonIdParser(b.get_data('fn'))
-                    f.new_lesson_id()
-                    lessonfile_manager.parse_into_uiddb(
-                        b.get_data('lessoncollection'),
-                        b.get_data('lessonfile'))
-                # and remove the duplicate entries from the entry we
-                # want to keep.
-                else:
-                    lessonfile_manager.delete_not_fn(lesson_id, b.get_data('fn'))
-        elif ret == gtk.RESPONSE_CANCEL:
-            lessonfile_manager.ignore_duplicates_with_lesson_id(lesson_id)
-        dlg.destroy()
-    if splash_win:
-        splash_win.show()
-
 if splash_win:
     splash_win.show_progress("running gnome.program_init")
 
@@ -714,7 +640,12 @@ if splash_win:
     splash_win.show_progress("creating LessonfileManager")
 lessonfile_manager = lessonfile.LessonFileManager()
 
-handle_lesson_id_crash(lessonfile_manager)
+if splash_win:
+    splash_win.hide()
+lessonfilegui.handle_lesson_id_crash(lessonfile_manager)
+if splash_win:
+    splash_win.show()
+
 lessonfile_manager.create_lessonfile_index()
 
 if splash_win:
