@@ -187,11 +187,14 @@ class Gui(abstract.IntervalGui):
         self.m_answer.append(interval)
         d = self.m_t.m_question[len(self.m_answer)-1]
         d = d / abs(d)
+        md = d
+        if self.g_input.know_directions():
+            md = 1
         if not self.msg:
-            self.msg = utils.int_to_intervalname(interval * d, 1, 1) + "+ ..."
+            self.msg = utils.int_to_intervalname(interval * md, 1, 1) + "+ ..."
         else:
             self.msg = self.msg[:-4]
-            self.msg = self.msg + utils.int_to_intervalname(interval * d, 1, 1) + "+ ..."
+            self.msg = self.msg + utils.int_to_intervalname(interval * md, 1, 1) + "+ ..."
         self.g_flashbar.push(self.msg)
         if len(self.m_answer) == self.m_number_of_intervals_in_question:
             if self.m_t.guess_answer(self.m_answer,
@@ -215,8 +218,12 @@ class Gui(abstract.IntervalGui):
         self.m_number_of_intervals_in_question \
                = self.get_int('number_of_intervals')
         self.m_answer = []
-        ret = self.m_t.new_question(self.get_string('user/lowest_pitch'),
+        if isinstance(self.g_input, inputwidgets.IntervalButtonsWidget):
+            ret = self.m_t.new_question(self.get_string('user/lowest_pitch'),
                                     self.get_string('user/highest_pitch'))
+        else:
+            ret = self.m_t.new_question(self.g_input.m_lowest_tone,
+                                    self.g_input.m_highest_tone)
         if ret == Teacher.ERR_CONFIGURE:
             self.g_flashbar.clear()
             self.g_flashbar.flash(_("The exercise has to be better configured."))
