@@ -1,5 +1,5 @@
 # GNU Solfege - ear training for GNOME
-# Copyright (C) 2000, 2001, 2002, 2003, 2004, 2005  Tom Cato Amundsen
+# Copyright (C) 2000, 2001, 2002, 2003, 2004, 2005, 2006  Tom Cato Amundsen
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -253,18 +253,59 @@ class RhythmViewer(gtk.Frame):
         l.set_alignment(0.0, 0.5)
         l.show()
         self.g_box.pack_start(l, True, True)
+        lx, ly = l.size_request()
+        sx, sy = self.g_box.size_request()
+        self.g_box.set_size_request(max(lx + gnome.ui.PAD * 2, sx), max(ly + gnome.ui.PAD * 2, sy))
         self.__timeout = gobject.timeout_add(const.NORMAL_WAIT, self.unflash)
     def unflash(self, *v):
         self.__timeout = None
         self.clear()
 
+class NewLineBox(gtk.VBox):
+    def __init__(self):
+        gtk.VBox.__init__(self)
+    def add_widget(self, widget):
+        self.m_todo_widgets.append(widget)
+    def show_widgets(self):
+        if 'newline' in self.m_todo_widgets:
+            self._newline_show_widgets()
+        else:
+            self._flow_show_widgets()
+    def newline(self):
+        self.m_todo_widgets.append('newline')
+    def _newline_show_widgets(self):
+        sizegroup = gtk.SizeGroup(gtk.SIZE_GROUP_HORIZONTAL)
+        hbox = gu.bHBox(self, True)
+        for n in self.m_todo_widgets:
+            if n == 'newline':
+                hbox = gu.bHBox(self, False)
+            else:
+                hbox.pack_start(n, False)
+                sizegroup.add_widget(n)
+    def _flow_show_widgets(self):
+        w = 8
+        num_lines = len(self.m_todo_widgets) // w + 1
+        w = len(self.m_todo_widgets) // num_lines + 1
+        sizegroup = gtk.SizeGroup(gtk.SIZE_GROUP_HORIZONTAL)
+        c = 0
+        for n in self.m_todo_widgets:
+            sizegroup.add_widget(n)
+            if c % w == 0:
+                hbox = gu.bHBox(self, False)
+            hbox.pack_start(n, False)
+            c += 1
+        self.show_all()
+    def empty(self):
+        self.foreach(lambda w: w.destroy())
+        self.m_todo_widgets = []
 
 class Gui(abstract.Gui):
     num_buttons_in_row = 8
     def __init__(self, teacher, window):
         abstract.Gui.__init__(self, teacher, window)
         self.m_key_bindings = {'backspace_ak': self.on_backspace}
-        self.g_answer_box = gu.bVBox(self.practise_box, False)
+        self.g_answer_box = NewLineBox()
+        self.practise_box.pack_start(self.g_answer_box, False)
         #-------
         self.practise_box.pack_start(gtk.HBox(), False,
                                      padding=gnome.ui.PAD_SMALL)
@@ -290,18 +331,9 @@ class Gui(abstract.Gui):
         ##############
         self.g_element_frame = frame = gtk.Frame(_("Rhythms to use in question"))
         self.config_box.pack_start(frame, False)
-        vbox = gtk.VBox()
-        vbox.set_border_width(gnome.ui.PAD_SMALL)
-        frame.add(vbox)
-        sizegroup = gtk.SizeGroup(gtk.SIZE_GROUP_HORIZONTAL)
-        self.m_element_check_buttons = {}
-        for i in range(len(RHYTHMS)):
-            if i % self.num_buttons_in_row == 0:
-                hbox = gu.bHBox(vbox, False)
-            b = self.pngcheckbutton(i)
-            self.m_element_check_buttons[i] = b
-            sizegroup.add_widget(b)
-            hbox.pack_start(b, False)
+        self.g_select_rhythms_box = NewLineBox()
+        self.g_select_rhythms_box.set_border_width(gnome.ui.PAD_SMALL)
+        frame.add(self.g_select_rhythms_box)
         #--------    
         self.config_box.pack_start(gtk.HBox(), False,
                                    padding=gnome.ui.PAD_SMALL)
@@ -364,14 +396,27 @@ class Gui(abstract.Gui):
         btn.connect('clicked', self.select_element_cb, i)
         return btn
     def select_element_cb(self, button, element_num):
+        def sortlike(orig, b):
+            ret = []
+            for n in orig:
+                if n == 'newline':
+                    ret.append('newline')
+                elif n in b:
+                    ret.append(n)
+            return ret
         if button.get_active():
             if element_num not in self.m_t.m_P.header.rhythm_elements:
                 self.m_t.m_P.header.rhythm_elements.append(element_num)
-                self.m_t.m_P.header.visible_rhythm_elements.append(element_num)
+                self.m_t.m_P.header.rhythm_elements = sortlike(
+                    self.m_t.m_P.header.configurable_rhythm_elements,
+                    self.m_t.m_P.header.rhythm_elements)
         else:
             if element_num in self.m_t.m_P.header.rhythm_elements:
                 self.m_t.m_P.header.rhythm_elements.remove(element_num)
-                self.m_t.m_P.header.visible_rhythm_elements.remove(element_num)
+        self.m_t.m_P.header.visible_rhythm_elements = \
+            self.m_t.m_P.header.rhythm_elements[:]
+        self.m_t.m_P.header.rhythm_elements = \
+            [n for n in self.m_t.m_P.header.rhythm_elements if n != 'newline']
         self.update_answer_buttons()
     def on_backspace(self, widget=None):
         if self.m_t.q_status == const.QSTATUS_SOLVED:
@@ -426,40 +471,44 @@ class Gui(abstract.Gui):
         self.m_t.play_question()
         self.g_first_rhythm_button.grab_focus()
     def update_select_elements_buttons(self):
-        for n in range(len(RHYTHMS)):
-            self.m_element_check_buttons[n].set_active(
-                n in self.m_t.m_P.header.rhythm_elements)
+        self.g_select_rhythms_box.empty()
+        for n in self.m_t.m_P.header.configurable_rhythm_elements:
+            if n == 'newline':
+                self.g_select_rhythms_box.newline()
+            else:
+                b = self.pngcheckbutton(n)
+                self.g_select_rhythms_box.add_widget(b)
+                b.set_active(n in self.m_t.m_P.header.rhythm_elements)
+        self.g_select_rhythms_box.show_widgets()
     def update_answer_buttons(self):
-        self.g_answer_box.foreach(lambda w: w.destroy())
-        w = self.num_buttons_in_row
-        c = 0
-        visible_rhythm_elements = self.m_t.m_P.header.visible_rhythm_elements
-        if not visible_rhythm_elements:
-            visible_rhythm_elements = self.m_t.m_P.header.rhythm_elements
-        num_lines = len(visible_rhythm_elements) // w + 1
-        # adjust the width, so that we don't get one last almost empty line
-        w = len(visible_rhythm_elements) // num_lines + 1
-        sizegroup = gtk.SizeGroup(gtk.SIZE_GROUP_HORIZONTAL)
-        for n in visible_rhythm_elements:
-            if c % w == 0:
-                hbox = gu.bHBox(self.g_answer_box, True)
-            b = self.pngbutton(n)
-            sizegroup.add_widget(b)
-            if c == 0:
-                self.g_first_rhythm_button = b
-            hbox.pack_start(b, False)
-            c += 1
+        self.g_answer_box.empty()
+        self.g_first_rhythm_button = None
+        for n in self.m_t.m_P.header.visible_rhythm_elements:
+            if n == 'newline':
+                self.g_answer_box.newline()
+            else:
+                b = self.pngbutton(n)
+                if not self.g_first_rhythm_button:
+                    self.g_first_rhythm_button = b
+                self.g_answer_box.add_widget(b)
+        self.g_answer_box.show_widgets()
     def on_start_practise(self):
         assert self.m_t.m_P
-        if not self.m_t.m_P.header.rhythm_elements:
-            self.m_t.m_custom_mode = True
-            self.m_t.m_P.header.rhythm_elements = [0, 1, 2]
-            self.m_t.m_P.header.visible_rhythm_elements = [0, 1, 2]
+        self.m_t.m_custom_mode = bool(self.m_t.m_P.header.configurable_rhythm_elements)
+        if self.m_t.m_custom_mode:
+            if not self.m_t.m_P.header.rhythm_elements:
+                self.m_t.m_P.header.rhythm_elements = self.m_t.m_P.header.configurable_rhythm_elements[:3]
+            self.m_t.m_P.header.visible_rhythm_elements = self.m_t.m_P.header.rhythm_elements[:]
         else:
-            self.m_t.m_custom_mode = False
-        self.update_select_elements_buttons()
+            if not self.m_t.m_P.header.visible_rhythm_elements:
+                self.m_t.m_P.header.visible_rhythm_elements = \
+                    self.m_t.m_P.header.rhythm_elements[:]
+                self.m_t.m_P.header.rhythm_elements = \
+                  [n for n in self.m_t.m_P.header.rhythm_elements if n != 'newline']
+        #
         self.update_answer_buttons()
         if self.m_t.m_custom_mode:
+            self.update_select_elements_buttons()
             self.g_element_frame.show()
         else:
             self.g_element_frame.hide()
