@@ -60,7 +60,7 @@ class Gui(abstract.LessonbasedGui):
         # config_box #
         ##############
         self.add_random_transpose_gui()
-        self.show_all()
+        self.practise_box.show_all()
     def new_question(self, widget):
         def exception_cleanup():
             soundcard.synth.stop()
