@@ -1,5 +1,5 @@
 # GNU Solfege - ear training for GNOME
-# Copyright (C) 2000, 2001, 2002, 2003, 2004, 2005  Tom Cato Amundsen
+# Copyright (C) 2000, 2001, 2002, 2003, 2004, 2005, 2006  Tom Cato Amundsen
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -140,6 +140,10 @@ class Gui(abstract.Gui):
             self.g_score_displayer.clear()
         return r
     def on_start_practise(self):
+        # First, we have to empty the cfg database because we will
+        # copy the values from the lesson header.
+        for i in range(self.get_int('maximum_number_of_intervals')):
+            self.set_list('ask_for_intervals_%i' % i, [])
         # If ask_for_intervals_0 is not set, then we run in custom_mode
         # where the user configure the exercise on her own.
         if self.m_t.m_P.header.ask_for_intervals_0:
@@ -147,7 +151,9 @@ class Gui(abstract.Gui):
                 if 'ask_for_intervals_%i' % i in self.m_t.m_P.header:
                     self.set_list('ask_for_intervals_%i' % i,
                       self.m_t.m_P.header['ask_for_intervals_%i' % i])
-            self.set_int('number_of_intervals', self.m_t.m_P.header.number_of_intervals)
+                else:
+                    break
+            self.set_int('number_of_intervals', i)
         self.m_t.m_custom_mode = bool(
                       not self.m_t.m_P.header.ask_for_intervals_0)
         if self.m_t.m_P.header.lesson_heading:
