@@ -302,7 +302,7 @@ class LessonStatistics(AbstractStatistics):
         else:
             return 0
     def get_hash_of_lessonfile(self):
-        return hash(open(os.path.expanduser(os.path.join(
+        return hash(open(gethomedir.expanduser(os.path.join(
             self.m_t.get_string('lessoncollections/%s' % self.m_cur_collection),
             self.m_cur_file))).read())
     def key_to_pretty_name(self, key):
