@@ -22,7 +22,6 @@ import cfg
 class Random(object):
     def __init__(self, choices):
         #TODO add assert that all choices are unique
-        print "xrandom.Random.init:", choices
         self.m_choices = choices
         self.m_choice_count = len(choices) * [0]
         # The number of randoms generated
@@ -65,8 +64,6 @@ class Random(object):
             f += v[2]
             v.append(f)
         selectval = data[-1][3] * random.random()
-        print "counts:", self.m_choice_count
-        print "weights:", [v[2] for v in data]
         for v in data:
             if selectval < v[3]:
                 return v[0]
@@ -77,7 +74,6 @@ class Random(object):
         has been selected few times are selected than questions that has
         been selected many times.
         """
-        print "random_by_random2()"
         if self.m_count == 0:
             return random.choice(available_choices)
         data = self.get_random_by_random_data(available_choices)
@@ -90,8 +86,6 @@ class Random(object):
             f += v[2]
             v.append(f)
         selectval = data[-1][3] * random.random()
-        print "\tcounts:", self.m_choice_count
-        print "\tweights:", [v[2] for v in data]
         for v in data:
             if selectval < v[3]:
                 return v[0]
@@ -102,17 +96,13 @@ class Random(object):
         Larger value make things more even.
         Smaller value make things more random.
         """
-        print "random_by_selection()"
         v = []
-        print "\tcounts:", self.m_choice_count
         if self.m_count > len(self.m_choices):
             for k in available_choices:
                 if self.m_choice_count[k] / self.m_count < 1 / (len(self.m_choices) * self.get_float("app/randomness")):
                     v.append(k)
             if v:
-                print "\tselected randomly from", v
                 return random.choice(v)
-        print "\tselected randomly from all choices"
         return random.choice(self.m_choices)
     def add(self, idx):
         self.m_choice_count[idx] += 1
